#  Copyright (c) 2005-2011 by Enthought, Inc.
#  All rights reserved.
""" Two-dimensional plotting application toolkit.
    Part of the Chaco project of the Enthought Tool Suite.
"""
__version__ = '4.1.0'

__requires__ = [
   'enable',
]
